@@ -415,7 +415,7 @@ class BinaryManager:
                     else:
                         disassembler = Cs(CS_ARCH_X86, CS_MODE_64)
                         disassembly = "\n".join(
-                            map(str(disassembler.disasm(data, offset)))
+                            map(str, disassembler.disasm(data, offset))
                         )
 
                     logger.debug(f"Disassembly of data for label {write.data.label}:")
